Resources
*********

The following references and learning materials explain SDMX *in general*:

- `SDMX page <https://en.wikipedia.org/wiki/SDMX>`_ on Wikipedia, with a simple summary in 6 languages.
- The **SDMX website** includes:

  - `the authoritative standards <https://sdmx.org/?page_id=5008>`_ (see :doc:`implementation` for more direct and specific links), and
  - `many detailed guidelines <https://sdmx.org/?page_id=4345>`_ for their use.

- The GitHub organization of the `SDMX Technical Standards Working Group <https://github.com/sdmx-twg>`_ GitHub organization hosts some standards information, such as:

  - https://github.com/sdmx-twg/sdmx-csv —SDMX-CSV format.
  - https://github.com/sdmx-twg/sdmx-json —SDMX-JSON format.
  - https://github.com/sdmx-twg/sdmx-ml —SDMX-ML format.
  - https://github.com/sdmx-twg/sdmx-rest —SDMX-REST web service API.

- Eurostat `SDMX ‘InfoSpace’ <https://ec.europa.eu/eurostat/web/sdmx-infospace/welcome>`_ contains many guides and tutorials, from beginner to advanced levels.
- European Central Bank `SDMX REST service help pages <https://sdw-wsrest.ecb.europa.eu/help/>`_ give many examples.
- `SDMXSource <http://www.sdmxsource.org>`_ provides reference implementations of SDMX in Java, .NET, and ActionScript.
- The :ref:`SDMX Global registry <SGR>` collects structures and data from many providers, useful for browsing and comparison.

Other software
==============

:mod:`sdmx` is not the only software implementation of the standards—and that's good!
For others, see:

- `“Tools” <https://sdmx.org/?page_id=4500>`_ and `“Implementations” <https://sdmx.org/?page_id=81>`_ on the SDMX website.
- Several provided by the :ref:`BIS` under the `sdmx.io <https://www.sdmx.io>`_ umbrella, including a Python package called `pysdmx <https://www.sdmx.io/tools/pysdmx/>`_ (`on GitHub <https://github.com/bis-med-it/pysdmx>`__) with a “pragmatic, opinionated” implementation.
